==> migrate_wizard-1.0.21-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericTextLong.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text_long' field type.
 *
 * @FieldType(
 *   id = "generic_text_long",
 * )
 */
class FieldTypeMWGenericTextLong extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    $origin_field_value = $origin_field;
    if ($origin_field == 'description' && $wildcard_yml_config["source"]["origin_type"] == 'taxonomy_term' && $langcode != NULL) {
      $origin_field_value = 'description_translated';
    }

    if($wildcard_yml_config["source"]["origin_type"] == 'taxonomy_term' && $wildcard_yml_config["destination"]["plugin"] == 'entity:node' && $origin_field == 'description'){
      $array_config[$data_field['destiny'].'/value'][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny'].'/format'][] = [
        'plugin' => 'static_map',
        'source' => 'format',
        'map' => $config->get('origin_formats'),
        'default_value' => 'full_html',
      ];
    }else{
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'method' => 'process',
        'process' => [
          'value' => 'value',
          'summary' => 'summary',
          'format' => [
            'plugin' => 'static_map',
            'source' => 'format',
            'map' => $config->get('origin_formats'),
            'default_value' => 'full_html',
          ]
        ],
      ];
    }

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);

  }
}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericTextLong.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text_long' field type.
 *
 * @FieldType(
 *   id = "generic_text_long",
 * )
 */
class FieldTypeMWGenericTextLong extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $shared_configuration, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    $origin_field_value = $origin_field;
    if ($origin_field == 'description' && $wildcard_yml_config["source"]["origin_type"] == 'taxonomy_term' && $langcode != NULL) {
      $origin_field_value = 'description_translated';
    }

    if($wildcard_yml_config["source"]["origin_type"] == 'taxonomy_term' && $wildcard_yml_config["destination"]["plugin"] == 'entity:node' && $origin_field == 'description'){
      $array_config[$data_field['destiny'].'/value'][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny'].'/format'][] = [
        'plugin' => 'static_map',
        'source' => 'format',
        'map' => $shared_configuration["origin_formats"],
        'default_value' => 'full_html',
      ];
    }else{
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'method' => 'process',
        'process' => [
          'value' => 'value',
          'summary' => 'summary',
          'format' => [
            'plugin' => 'static_map',
            'source' => 'format',
            'map' => $shared_configuration["origin_formats"],
            'default_value' => 'full_html',
          ]
        ],
      ];
    }

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);

  }
}
